netapp_ontap.models.cifs_domain_discovered_server API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cifs_domain_discovered_server`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class CifsDomainDiscoveredServerSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the CifsDomainDiscoveredServer object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `domain: str GET POST PATCH`

    Fully Qualified Domain Name.

    Example: test.com

  `node: Node GET POST PATCH`

    The node field of the cifs_domain_discovered_server.

  `preference: str GET POST PATCH`

    Server Preference

    Valid choices:

    - unknown
    - preferred
    - favored
    - adequate
  `server_ip: str GET POST PATCH`

    Server IP address

  `server_name: str GET POST PATCH`

    Server Name

  `server_type: str GET POST PATCH`

    Server Type

    Valid choices:

    - unknown
    - kerberos
    - ms_ldap
    - ms_dc
    - ldap
  `state: str GET POST PATCH`

    Server status

    Valid choices:

    - ok
    - unavailable
    - slow
    - expired
    - undetermined
    - unreachable